from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_ansible.api.ansible_collections_api import AnsibleCollectionsApi
from pulpcore.client.pulp_ansible.api.ansible_copy_api import AnsibleCopyApi
from pulpcore.client.pulp_ansible.api.api_collections_api import ApiCollectionsApi
from pulpcore.client.pulp_ansible.api.api_roles_api import ApiRolesApi
from pulpcore.client.pulp_ansible.api.collection_import_api import CollectionImportApi
from pulpcore.client.pulp_ansible.api.content_collection_deprecations_api import ContentCollectionDeprecationsApi
from pulpcore.client.pulp_ansible.api.content_collection_versions_api import ContentCollectionVersionsApi
from pulpcore.client.pulp_ansible.api.content_roles_api import ContentRolesApi
from pulpcore.client.pulp_ansible.api.distributions_ansible_api import DistributionsAnsibleApi
from pulpcore.client.pulp_ansible.api.galaxy_detail_api import GalaxyDetailApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_api import PulpAnsibleApiApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v2_collections_versions_api import PulpAnsibleApiV2CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_api import PulpAnsibleApiV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collection_versions_all_api import PulpAnsibleApiV3CollectionVersionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_api import PulpAnsibleApiV3CollectionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_all_api import PulpAnsibleApiV3CollectionsAllApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_api import PulpAnsibleApiV3CollectionsVersionsApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_api_v3_collections_versions_docs_blob_api import PulpAnsibleApiV3CollectionsVersionsDocsBlobApi
from pulpcore.client.pulp_ansible.api.pulp_ansible_artifacts_collections_v3_api import PulpAnsibleArtifactsCollectionsV3Api
from pulpcore.client.pulp_ansible.api.pulp_ansible_tags_api import PulpAnsibleTagsApi
from pulpcore.client.pulp_ansible.api.remotes_collection_api import RemotesCollectionApi
from pulpcore.client.pulp_ansible.api.remotes_git_api import RemotesGitApi
from pulpcore.client.pulp_ansible.api.remotes_role_api import RemotesRoleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_api import RepositoriesAnsibleApi
from pulpcore.client.pulp_ansible.api.repositories_ansible_versions_api import RepositoriesAnsibleVersionsApi
from pulpcore.client.pulp_ansible.api.versions_api import VersionsApi



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_ansible
from pulpcore.client.pulp_ansible.models.ansible_git_remote import AnsibleGitRemote  # noqa: E501
from pulpcore.client.pulp_ansible.rest import ApiException

class TestAnsibleGitRemote(unittest.TestCase):
    """AnsibleGitRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AnsibleGitRemote
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_ansible.models.ansible_git_remote.AnsibleGitRemote()  # noqa: E501
        if include_optional :
            return AnsibleGitRemote(
                proxy_username = '0', 
                proxy_url = '0', 
                max_retries = 56, 
                connect_timeout = 0.0, 
                tls_validation = True, 
                username = '0', 
                rate_limit = 56, 
                client_key = '0', 
                client_cert = '0', 
                sock_connect_timeout = 0.0, 
                download_concurrency = 1, 
                pulp_labels = None, 
                proxy_password = '0', 
                headers = [
                    None
                    ], 
                sock_read_timeout = 0.0, 
                name = '0', 
                url = '0', 
                total_timeout = 0.0, 
                ca_cert = '0', 
                password = '0', 
                metadata_only = True, 
                git_ref = '0'
            )
        else :
            return AnsibleGitRemote(
                name = '0',
                url = '0',
        )

    def testAnsibleGitRemote(self):
        """Test AnsibleGitRemote"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
